createElement method
Creates a StatefulElement to manage this widget's location in the tree.
It is uncommon for subclasses to override this method.
Implementation
@nonVirtual
@override
StatefulElement createElement() => VibeStatefulElement(this);
Creates a StatefulElement to manage this widget's location in the tree.
It is uncommon for subclasses to override this method.
@nonVirtual
@override
StatefulElement createElement() => VibeStatefulElement(this);