VibeWidget class abstract

Vibe version of StatelessWidget

Inheritance
Mixed-in types
Implementers

Constructors

VibeWidget({Key? key})
const

Properties

$container VibeContainer
no setteroverride
$state VibeWidgetState<VibeStatefulWidget>?
no setter
$subscriptions Map<dynamic, StreamSubscription>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vibes List
Fields expected as Vibes
no setter

Methods

build(BuildContext context) Widget
Same as the StatelessWidget.build
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() VibeWidgetState<VibeStatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
dispose() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange() → void
override
subscribe(dynamic key, Stream stream) → void
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
unsubscribe(dynamic key) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited