Vibe class
Marks a class as it is a reactive state class
- Annotations
-
- @Target.new(<TargetKind>{TargetKind.classType, TargetKind.enumType})
Properties
- autoDispose → bool
-
Wheter disposing the state automatically
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited