VibeObservableObserver class abstract
- Mixed-in types
Constructors
Properties
-
$subscriptions
→ Map<
dynamic, StreamSubscription> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onChange(
) → void -
inherited
-
subscribe(
dynamic key, Stream stream) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unsubscribe(
dynamic key) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited